@@ -29,11 +29,10 @@
 --
 -- @type 'Getter' s a = forall r. 'Getting' r s a@
 --
--- But we actually hide the use of 'Const' behind a class 'Gettable' to
--- report error messages from type class resolution rather than at unification
--- time, where they are much uglier.
+-- However, for 'Getter' (but not for 'Getting') we actually permit any
+-- functor @f@ which is an instance of both 'Functor' and 'Contravariant':
 --
--- @type 'Getter' s a = forall f. 'Gettable' f => (a -> f a) -> s -> f s@
+-- @type 'Getter' s a = forall f. ('Contravariant' f, 'Functor' f) => (a -> f a) -> s -> f s@
 --
 -- Everything you can do with a function, you can do with a 'Getter', but
 -- note that because of the continuation passing style ('.') composes them
@@ -67,7 +66,6 @@ module Control.Lens.Getter
   , Contravariant(..)
   , coerce, coerced
   , Const(..)
-  , Gettable
   ) where
 
 import Control.Applicative
@@ -457,7 +455,8 @@ iuses l = uses l .# Indexed
 s ^@. l = getConst $ l (Indexed $ \i -> Const #. (,) i) s
 {-# INLINE (^@.) #-}
 
--- | Coerce a 'Gettable' 'LensLike' to a 'Simple' 'LensLike'. This is useful
--- when using a 'Traversal' that is not simple as a 'Getter' or a 'Fold'.
+-- | Coerce a 'Getter'-compatible 'LensLike' to a 'Simple' 'LensLike'. This
+-- is useful when using a 'Traversal' that is not simple as a 'Getter' or a
+-- 'Fold'.
 coerced :: (Functor f, Contravariant f) => LensLike f s t a b -> LensLike' f s a
 coerced l f = coerce . l (coerce . f)
