@@ -160,10 +160,10 @@ cloneIso k = withIso k iso
 --
 -- This version is generalized to accept any 'Iso', not just a @newtype@.
 --
--- >>> au (_Unwrapping Sum) foldMap [1,2,3,4]
+-- >>> au (_Wrapping Sum) foldMap [1,2,3,4]
 -- 10
-au :: AnIso s t a b -> ((s -> a) -> e -> b) -> e -> t
-au k = withIso k $ \ sa bt f e -> bt (f sa e)
+au :: AnIso s t a b -> ((b -> t) -> e -> s) -> e -> a
+au k = withIso k $ \ sa bt f e -> sa (f bt e)
 {-# INLINE au #-}
 
 -- | Based on @ala'@ from Conor McBride's work on Epigram.
@@ -255,6 +255,14 @@ mapping k = withIso k $ \ sa bt -> iso (fmap sa) (fmap bt)
 --
 -- >>> fromList [("hello",fromList [("world","!!!")])] & at "hello" . non Map.empty . at "world" .~ Nothing
 -- fromList []
+--
+-- It can also be used in reverse to exclude a given value:
+--
+-- >>> non 0 # rem 10 4
+-- Just 2
+--
+-- >>> non 0 # rem 10 5
+-- Nothing
 non :: Eq a => a -> Iso' (Maybe a) a
 non = non' . only
 {-# INLINE non #-}
@@ -489,8 +497,8 @@ rmapping g = withIso g $ \ sa bt -> iso (rmap sa) (rmap bt)
 -- | Lift two 'Iso's into both arguments of a 'Bifunctor'.
 --
 -- @
--- bimapping :: 'Profunctor' p => 'Iso' s t a b -> 'Iso' s' t' a' b' -> 'Iso' (p s s') (p t t') (p a a') (p b b')
--- bimapping :: 'Profunctor' p => 'Iso'' s a -> 'Iso'' s' a' -> 'Iso'' (p s s') (p a a')
+-- bimapping :: 'Bifunctor' p => 'Iso' s t a b -> 'Iso' s' t' a' b' -> 'Iso' (p s s') (p t t') (p a a') (p b b')
+-- bimapping :: 'Bifunctor' p => 'Iso'' s a -> 'Iso'' s' a' -> 'Iso'' (p s s') (p a a')
 -- @
 bimapping :: (Bifunctor f, Bifunctor g) => AnIso s t a b -> AnIso s' t' a' b' -> Iso (f s s') (g t t') (f a a') (g b b')
 bimapping f g = withIso f $ \ sa bt -> withIso g $ \s'a' b't' ->
