@@ -51,6 +51,7 @@ module Control.Lens.TH
   , simpleLenses
   , createClass
   , generateSignatures
+  , generateUpdateableOptics
   ) where
 
 import Control.Applicative
@@ -100,6 +101,14 @@ generateSignatures :: Lens' LensRules Bool
 generateSignatures f r =
   fmap (\x -> r { _generateSigs = x}) (f (_generateSigs r))
 
+-- | Generate "updateable" optics when 'True'. When 'False', 'Fold's will be
+-- generated instead of 'Traversal's and 'Getter's will be generated instead
+-- of 'Lens'es. This mode is intended to be used for types with invariants
+-- which must be maintained by "smart" constructors.
+generateUpdateableOptics :: Lens' LensRules Bool
+generateUpdateableOptics f r =
+  fmap (\x -> r { _allowUpdates = x}) (f (_allowUpdates r))
+
 -- | Create the class if the constructor is 'Control.Lens.Type.Simple' and the
 -- 'lensClass' rule matches.
 createClass :: Lens' LensRules Bool
@@ -137,6 +146,7 @@ lensRules = LensRules
   , _generateSigs    = True
   , _generateClasses = False
   , _allowIsos       = True
+  , _allowUpdates    = True
   , _classyLenses    = const Nothing
   , _fieldToDef      = \_ _ n ->
        case nameBase n of
@@ -162,6 +172,7 @@ classyRules = LensRules
   , _generateSigs    = True
   , _generateClasses = True
   , _allowIsos       = False -- generating Isos would hinder "subtyping"
+  , _allowUpdates    = True
   , _classyLenses    = \n ->
         case nameBase n of
           x:xs -> Just (mkName ("Has" ++ x:xs), mkName (toLower x:xs))
@@ -667,6 +678,7 @@ defaultFieldRules = LensRules
   , _generateSigs    = True
   , _generateClasses = True  -- classes will still be skipped if they already exist
   , _allowIsos       = False -- generating Isos would hinder field class reuse
+  , _allowUpdates    = True
   , _classyLenses    = const Nothing
   , _fieldToDef      = camelCaseNamer
   }
