@@ -12,6 +12,7 @@
 #ifdef TRUSTWORTHY
 {-# LANGUAGE Trustworthy #-}
 #endif
+{-# OPTIONS_GHC -fno-warn-warnings-deprecations #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Control.Lens.Wrapped
@@ -96,6 +97,10 @@ import qualified Data.Semigroup as S
 import           Data.Sequence as Seq hiding (length)
 import           Data.Set as Set
 import           Data.Tagged
+import           Data.Vector as Vector
+import           Data.Vector.Primitive as Prim
+import           Data.Vector.Unboxed as Unboxed
+import           Data.Vector.Storable as Storable
 
 -- $setup
 -- >>> :set -XNoOverloadedStrings
@@ -119,7 +124,7 @@ _Unwrapped' = from _Wrapped'
 
 -- | Work under a newtype wrapper.
 --
--- >>> Const "hello" & _Wrapped %~ length & getConst
+-- >>> Const "hello" & _Wrapped %~ Prelude.length & getConst
 -- 5
 --
 -- @
@@ -386,6 +391,32 @@ instance Wrapped (Seq a) where
   _Wrapped' = iso Foldable.toList Seq.fromList
   {-# INLINE _Wrapped' #-}
 
+-- * vector
+
+instance (t ~ Vector.Vector a') => Rewrapped (Vector.Vector a) t
+instance Wrapped (Vector.Vector a) where
+  type Unwrapped (Vector.Vector a) = [a]
+  _Wrapped' = iso Vector.toList Vector.fromList
+  {-# INLINE _Wrapped' #-}
+
+instance (Prim a, t ~ Prim.Vector a') => Rewrapped (Prim.Vector a) t
+instance Prim a => Wrapped (Prim.Vector a) where
+  type Unwrapped (Prim.Vector a) = [a]
+  _Wrapped' = iso Prim.toList Prim.fromList
+  {-# INLINE _Wrapped' #-}
+
+instance (Unbox a, t ~ Unboxed.Vector a') => Rewrapped (Unboxed.Vector a) t
+instance Unbox a => Wrapped (Unboxed.Vector a) where
+  type Unwrapped (Unboxed.Vector a) = [a]
+  _Wrapped' = iso Unboxed.toList Unboxed.fromList
+  {-# INLINE _Wrapped' #-}
+
+instance (Storable a, t ~ Storable.Vector a') => Rewrapped (Storable.Vector a) t
+instance Storable a => Wrapped (Storable.Vector a) where
+  type Unwrapped (Storable.Vector a) = [a]
+  _Wrapped' = iso Storable.toList Storable.fromList
+  {-# INLINE _Wrapped' #-}
+
 -- * semigroups
 
 instance (t ~ S.Min b) => Rewrapped (S.Min a) t
@@ -625,14 +656,14 @@ _Unwrapping _ = from _Wrapped
 -- >>> ala Product foldMap [1,2,3,4]
 -- 24
 ala :: Rewrapping s t => (Unwrapped s -> s) -> ((Unwrapped t -> t) -> e -> s) -> e -> Unwrapped s
-ala = au . _Unwrapping
+ala = au . _Wrapping
 {-# INLINE ala #-}
 
 -- | This combinator is based on @ala'@ from Conor McBride's work on Epigram.
 --
 -- As with '_Wrapping', the user supplied function for the newtype is /ignored/.
 --
--- >>> alaf Sum foldMap length ["hello","world"]
+-- >>> alaf Sum foldMap Prelude.length ["hello","world"]
 -- 10
 alaf :: (Profunctor p, Rewrapping s t) => (Unwrapped s -> s) -> (p r t -> e -> s) -> p r (Unwrapped t) -> e -> Unwrapped s
 alaf = auf . _Unwrapping
