@@ -29,7 +29,6 @@ module Control.Lens.Zoom
   ) where
 
 import Control.Lens.Getter
-import Control.Lens.Internal.Action
 import Control.Lens.Internal.Zoom
 import Control.Lens.Type
 import Control.Monad
@@ -50,6 +49,7 @@ import Control.Monad.Trans.Identity
 import Control.Monad.Trans.Maybe
 import Data.Monoid
 import Data.Profunctor.Unsafe
+import Prelude
 
 -- $setup
 -- >>> import Control.Lens
